@@ -1,13 +1,23 @@
 import math
 
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import OffensiveStatusEffectSpec
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
+from ama_xiv_combat_sim.simulator.specs.trigger_spec import TriggerSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.caster.smn_data import (
     all_smn_skills,
@@ -31,6 +41,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -45,6 +56,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -59,6 +71,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -73,6 +86,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -88,6 +102,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -103,6 +118,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -126,6 +142,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -140,6 +157,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -155,6 +173,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -175,6 +194,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -195,7 +215,8 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            buff_spec=StatusEffectSpec(
+            skill_type=SkillType.ABILITY,
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 damage_mult=self._skill_data.get_skill_data(name, "damage_mult"),
                 duration=self._skill_data.get_skill_data(name, "duration"),
                 is_party_effect=True,
@@ -208,7 +229,6 @@ class SmnSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec={
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
                         potency=self._skill_data.get_potency(name),
@@ -232,6 +252,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(self.__get_akh_morn_for_follow_up(),),
             has_aoe=True,
@@ -243,6 +264,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(self.__get_akh_morn_for_follow_up(),),
         )
@@ -253,6 +275,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=2800,
@@ -268,6 +291,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -284,6 +308,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -301,6 +326,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
@@ -315,6 +341,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -329,6 +356,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -343,7 +371,6 @@ class SmnSkills(GenericJobClass):
         return FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec={
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -369,6 +396,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(self.__get_revelation_follow_up(),),
         )
@@ -379,6 +407,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(self.__get_revelation_follow_up(),),
         )
@@ -389,6 +418,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=2800,
@@ -405,6 +435,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -422,6 +453,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -440,6 +472,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -451,7 +484,7 @@ class SmnSkills(GenericJobClass):
                 application_delay=800,
             ),
             has_aoe=True,
-            aoe_dropoff=0.65,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -460,6 +493,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -471,7 +505,7 @@ class SmnSkills(GenericJobClass):
                 application_delay=760,
             ),
             has_aoe=True,
-            aoe_dropoff=0.65,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -480,6 +514,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -491,7 +526,7 @@ class SmnSkills(GenericJobClass):
                 application_delay=760,
             ),
             has_aoe=True,
-            aoe_dropoff=0.7,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -500,7 +535,6 @@ class SmnSkills(GenericJobClass):
         slipstream_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency(name),
                     damage_class=DamageClass.MAGICAL_DOT,
@@ -518,6 +552,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -531,7 +566,7 @@ class SmnSkills(GenericJobClass):
             ),
             follow_up_skills=(slipstream_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.65,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -541,7 +576,6 @@ class SmnSkills(GenericJobClass):
         inferno_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=True,
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec={
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -552,7 +586,7 @@ class SmnSkills(GenericJobClass):
                     )
                 },
                 has_aoe=True,
-                aoe_dropoff=0.6,
+                aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
             ),
             snapshot_buffs_with_parent=False,
             snapshot_debuffs_with_parent=False,
@@ -564,6 +598,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(inferno_follow_up,),
         )
@@ -575,7 +610,6 @@ class SmnSkills(GenericJobClass):
         earthen_fury_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=True,
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec={
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -586,7 +620,7 @@ class SmnSkills(GenericJobClass):
                     )
                 },
                 has_aoe=True,
-                aoe_dropoff=0.6,
+                aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
             ),
             snapshot_buffs_with_parent=False,
             snapshot_debuffs_with_parent=False,
@@ -598,6 +632,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(earthen_fury_follow_up,),
             has_aoe=True,
@@ -610,7 +645,6 @@ class SmnSkills(GenericJobClass):
         aerial_blast_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=True,
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec={
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -621,7 +655,7 @@ class SmnSkills(GenericJobClass):
                     )
                 },
                 has_aoe=True,
-                aoe_dropoff=0.6,
+                aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
             ),
             snapshot_buffs_with_parent=False,
             snapshot_debuffs_with_parent=False,
@@ -633,6 +667,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(aerial_blast_follow_up,),
         )
@@ -645,6 +680,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -661,6 +697,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -674,7 +711,6 @@ class SmnSkills(GenericJobClass):
         name = "Scarlet Flame (pet)"
         return Skill(
             name=name,
-            is_GCD=False,
             status_effect_denylist=("Dragon Sight",),
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
@@ -690,6 +726,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             status_effect_denylist=("Dragon Sight",),
             timing_spec=self.auto_timing_spec,
             follow_up_skills=(
@@ -702,6 +739,59 @@ class SmnSkills(GenericJobClass):
             ),
         )
 
+    # This is going to require special treatment because of the naming,
+    # but the skill and the buff have the same name and this triggers
+    # conditionally.
+    @GenericJobClass.is_a_skill
+    def rekindle_buff(self):
+        name = "Rekindle (Buff)"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            heal_spec=HealSpec(
+                hot_potency=200, duration=15 * 1000, is_party_effect=True
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def rekindle(self):
+        name = "Rekindle"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            timing_spec=self.instant_timing_spec,
+            skill_type=SkillType.ABILITY,
+            heal_spec=HealSpec(potency=400, is_party_effect=True),
+            trigger_spec=TriggerSpec(triggers=("Rekindle (Buff)",)),
+        )
+
+    @GenericJobClass.is_a_skill
+    def lux_solaris(self):
+        if self._level < 100:
+            return None
+        name = "Lux Solaris"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            timing_spec=self.instant_timing_spec,
+            skill_type=SkillType.ABILITY,
+            heal_spec=HealSpec(potency=500, is_party_effect=True, is_aoe=True),
+        )
+
+    # Convenience for logs parsing
+    @GenericJobClass.is_a_skill
+    def everlasting_flight(self):
+        name = "Everlasting Flight"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            heal_spec=HealSpec(
+                hot_potency=100, duration=21 * 1000, is_party_effect=True, is_aoe=True
+            ),
+        )
+
     @GenericJobClass.is_a_skill
     def summon_phoenix(self):
         name = "Summon Phoenix"
@@ -711,6 +801,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (
@@ -738,8 +829,17 @@ class SmnSkills(GenericJobClass):
                         snapshot_buffs_with_parent=False,
                         snapshot_debuffs_with_parent=False,
                     ),
+                    FollowUp(
+                        skill=self.everlasting_flight(),
+                        delay_after_parent_application=0,
+                    ),
+                ),
+                "Manual": (
+                    FollowUp(
+                        skill=self.everlasting_flight(),
+                        delay_after_parent_application=0,
+                    ),
                 ),
-                "Manual": tuple(),
             },
         )
 
@@ -747,7 +847,6 @@ class SmnSkills(GenericJobClass):
         name = "Wyrmwave (pet)"
         return Skill(
             name=name,
-            is_GCD=False,
             status_effect_denylist=("Dragon Sight",),
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
@@ -764,6 +863,7 @@ class SmnSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=False,
+                skill_type=SkillType.ABILITY,
                 timing_spec=self.auto_timing_spec,
                 follow_up_skills=(
                     FollowUp(
@@ -783,6 +883,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (
@@ -822,6 +923,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=display_name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency("Luxwave"),
                 damage_class=DamageClass.PET,
@@ -841,6 +943,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (
@@ -881,6 +984,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -897,6 +1001,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -914,6 +1019,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -935,7 +1041,6 @@ class SmnSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec={
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
                         potency=self._skill_data.get_potency(name),
@@ -962,6 +1067,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=display_name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(self.__get_exodus_follow_up(),),
         )
@@ -974,10 +1080,57 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
             follow_up_skills=(self.__get_exodus_follow_up(),),
         )
 
+    @GenericJobClass.is_a_skill
+    def physick(self):
+        name = "Physick"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.SPELL,
+            timing_spec=TimingSpec(
+                base_cast_time=1500, animation_lock=self.__base_animation_lock
+            ),
+            heal_spec=HealSpec(potency=400, is_party_effect=True),
+        )
+
+    @GenericJobClass.is_a_skill
+    def radiant_aegis(self):
+        name = "Radiant Aegis"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            shield_spec=ShieldSpec(
+                shield_on_max_hp=0.2, duration=30 * 1000, is_party_effect=False
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def addle(self):
+        name = "Addle"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=(
+                    {
+                        DamageInstanceClass.PHYSICAL: 0.05,
+                        DamageInstanceClass.MAGICAL: 0.1,
+                    }
+                ),
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
@@ -988,8 +1141,9 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=self.__smn_instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 duration=15 * 1000,
                 num_uses=1,
                 add_to_skill_modifier_condition=True,
@@ -1003,8 +1157,9 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__smn_instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 flat_cast_time_reduction=math.inf,
                 duration=10 * 1000,
                 num_uses=1,
@@ -1014,6 +1169,7 @@ class SmnSkills(GenericJobClass):
                     "Tri-disaster",
                     "Ruby Catastrophe",
                     "Slipstream",
+                    "Physick",
                 ),
             ),
         )
@@ -1024,6 +1180,7 @@ class SmnSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             timing_spec=TimingSpec(
                 base_cast_time=1500,
                 animation_lock=self.__smn_caster_tax_ms,
@@ -1033,19 +1190,39 @@ class SmnSkills(GenericJobClass):
     @GenericJobClass.is_a_skill
     def summon_ifrit(self):
         name = "Summon Ifrit"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__smn_instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,
+            skill_type=SkillType.SPELL,
+            timing_spec=self.__smn_instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def summon_titan(self):
         name = "Summon Titan"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__smn_instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,
+            skill_type=SkillType.SPELL,
+            timing_spec=self.__smn_instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def summon_garuda(self):
         name = "Summon Garuda"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__smn_instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,
+            skill_type=SkillType.SPELL,
+            timing_spec=self.__smn_instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def astral_flow(self):
         name = "Astral Flow"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__smn_instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,
+            skill_type=SkillType.SPELL,
+            timing_spec=self.__smn_instant_timing_spec,
+        )
