@@ -27,8 +27,18 @@ ALL_DATA = {
         100: {"potency": {"7.0": 400}},
     },
     "Stellar Explosion (pet)": {
-        90: {"Earthly Dominance": {"6.55": 205}, "Giant Dominance": {"6.55": 310}},
-        100: {"Earthly Dominance": {"7.0": 205}, "Giant Dominance": {"7.0": 310}},
+        90: {
+            "Earthly Dominance": {"6.55": 205},
+            "Giant Dominance": {"6.55": 310},
+            "Earthly Dominance (Heal)": {"6.55": 540},
+            "Giant Dominance (Heal)": {"6.55": 720},
+        },
+        100: {
+            "Earthly Dominance": {"7.0": 205},
+            "Giant Dominance": {"7.0": 310},
+            "Earthly Dominance (Heal)": {"7.0": 540},
+            "Giant Dominance (Heal)": {"7.0": 720},
+        },
     },
     "Oracle": {
         100: {
@@ -36,6 +46,10 @@ ALL_DATA = {
             "aoe_dropoff": {"7.0": 0, "7.2": 0.5},
         }
     },
+    "Collective Unconscious": {
+        90: {"duration": {"6.55": 5*1000, "7.4": 10*1000}},
+        100: {"duration": {"7.0": 5*1000, "7.4": 10*1000}},
+    },
 }
 
 for k, v in ALL_DATA.items():
