@@ -1,5 +1,9 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.specs.channeling_spec import ChannelingSpec
 from ama_xiv_combat_sim.simulator.specs.job_resource_settings import JobResourceSettings
 from ama_xiv_combat_sim.simulator.specs.job_resource_spec import JobResourceSpec
@@ -8,7 +12,14 @@ from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.melee.nin_data import (
@@ -72,7 +83,6 @@ class NinSkills(GenericJobClass):
             all_bunshin_follow_ups[sk] = FollowUp(
                 skill=Skill(
                     name=f"{sk} (pet)",
-                    is_GCD=False,
                     damage_spec=DamageSpec(
                         potency=bunshin_potency,
                         damage_class=DamageClass.PET,
@@ -104,7 +114,6 @@ class NinSkills(GenericJobClass):
         res = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             ),
             delay_after_parent_application=0,
@@ -118,8 +127,7 @@ class NinSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.15,
                     auto_attack_delay_reduction=0.15,
                     duration=60 * 1000,
@@ -136,8 +144,7 @@ class NinSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.15,
                     auto_attack_delay_reduction=0.15,
                     duration=10 * 1000,
@@ -152,8 +159,7 @@ class NinSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.15,
                     auto_attack_delay_reduction=0.15,
                     duration=30 * 1000,
@@ -163,6 +169,19 @@ class NinSkills(GenericJobClass):
             delay_after_parent_application=0,
         )
 
+    @GenericJobClass.is_a_skill
+    def auto(self):
+        name = "Auto"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.AUTO,
+            timing_spec=self.auto_timing_spec,
+            damage_spec=DamageSpec(
+                potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
+            ),
+        )
+
     @GenericJobClass.is_a_skill
     def dream_within_a_dream(self):
         name = "Dream Within a Dream"
@@ -170,7 +189,6 @@ class NinSkills(GenericJobClass):
             FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 snapshot_buffs_with_parent=True,
@@ -180,7 +198,6 @@ class NinSkills(GenericJobClass):
             FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 snapshot_buffs_with_parent=True,
@@ -190,7 +207,6 @@ class NinSkills(GenericJobClass):
             FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 snapshot_buffs_with_parent=True,
@@ -201,22 +217,11 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
             follow_up_skills=_dream_follow_ups,
         )
 
-    @GenericJobClass.is_a_skill
-    def auto(self):
-        name = "Auto"
-        return Skill(
-            name=name,
-            is_GCD=False,
-            timing_spec=self.auto_timing_spec,
-            damage_spec=DamageSpec(
-                potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
-            ),
-        )
-
     @GenericJobClass.is_a_skill
     def doton(self):
         name = "Doton (dot)"
@@ -224,7 +229,6 @@ class NinSkills(GenericJobClass):
         doton_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency(name),
                     damage_class=DamageClass.PHYSICAL_DOT,
@@ -234,12 +238,14 @@ class NinSkills(GenericJobClass):
             dot_duration=self._skill_data.get_skill_data(name, "duration"),
             snapshot_buffs_with_parent=True,
             snapshot_debuffs_with_parent=False,
+            primary_target_only=False,
         )
         name = "Doton"
         return Skill(
             name=name,
             is_GCD=True,
-            buff_spec=StatusEffectSpec(
+            skill_type=SkillType.WEAPONSKILL,
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 duration=self._skill_data.get_skill_data("Doton (dot)", "duration"),
             ),
@@ -264,12 +270,11 @@ class NinSkills(GenericJobClass):
 
     @GenericJobClass.is_a_skill
     def hollow_nozuchi(self):
-        # TODO: fix. gcds only will proc it, like bunshin. Ty An.
-        # hollow nozuchi procs every time an aoe gcd is used while doton is down
         name = "Hollow Nozuchi"
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=0, application_delay=0
@@ -289,6 +294,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
@@ -324,6 +330,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Spinning Edge",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
@@ -355,6 +362,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
             ),
@@ -382,7 +390,7 @@ class NinSkills(GenericJobClass):
         mug_debuff_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                debuff_spec=StatusEffectSpec(
+                offensive_debuff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.05,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
@@ -393,6 +401,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (
@@ -428,7 +437,7 @@ class NinSkills(GenericJobClass):
         trick_debuff_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                debuff_spec=StatusEffectSpec(
+                offensive_debuff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.10, duration=int(15.77 * 1000)
                 ),
             ),
@@ -437,6 +446,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (
                     trick_damage_follow_up,
@@ -584,6 +594,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Gust Slash",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
@@ -611,6 +622,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
@@ -653,6 +665,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Death Blossom",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
@@ -756,6 +769,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Gust Slash",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
@@ -815,6 +829,21 @@ class NinSkills(GenericJobClass):
             },
         )
 
+    # for logs processing convenience
+    @GenericJobClass.is_a_skill
+    def dokumori_debuff(self):
+        if self._version <= "6.55":
+            return None
+
+        return Skill(
+            name="Dokumori (Debuff Only)",
+            offensive_debuff_spec=OffensiveStatusEffectSpec(
+                damage_mult=1.05,
+                duration=self._skill_data.get_skill_data("Dokumori", "duration"),
+                is_party_effect=True,
+            ),
+        )
+
     @GenericJobClass.is_a_skill
     def dokumori(self):
         if self._version <= "6.55":
@@ -824,7 +853,7 @@ class NinSkills(GenericJobClass):
         dokumori_debuff_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                debuff_spec=StatusEffectSpec(
+                offensive_debuff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.05,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
@@ -850,6 +879,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
             ),
@@ -873,6 +903,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=800
@@ -892,6 +923,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=800
@@ -905,6 +937,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -945,6 +978,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(base_cast_time=0),
             status_effect_denylist=("Dragon Sight",),
             follow_up_skills={
@@ -959,6 +993,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -975,6 +1010,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=760
@@ -991,6 +1027,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
@@ -1018,6 +1055,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
@@ -1047,6 +1085,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
@@ -1072,6 +1111,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
@@ -1097,6 +1137,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=self._skill_data.get_skill_data(name, "damage_spec"),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
@@ -1127,6 +1168,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
@@ -1155,6 +1197,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -1175,6 +1218,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -1191,8 +1235,9 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=5,
                 duration=int(30.7 * 1000),
@@ -1206,8 +1251,9 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=3,
                 duration=6000,
@@ -1224,8 +1270,9 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=30 * 1000,
@@ -1251,7 +1298,7 @@ class NinSkills(GenericJobClass):
         kunai_debuff_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                debuff_spec=StatusEffectSpec(
+                offensive_debuff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.10,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                 ),
@@ -1262,6 +1309,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
             ),
@@ -1278,6 +1326,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=800
@@ -1292,6 +1341,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -1313,6 +1363,7 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1690
@@ -1327,8 +1378,9 @@ class NinSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=15 * 1000,
@@ -1345,31 +1397,110 @@ class NinSkills(GenericJobClass):
             ),
         )
 
+    @GenericJobClass.is_a_skill
+    def shade_shift(self):
+        name = "Shade Shift"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            shield_spec=ShieldSpec(
+                shield_on_max_hp=0.2, duration=20 * 1000, is_party_effect=False
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def feint(self):
+        name = "Feint"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions={
+                    DamageInstanceClass.PHYSICAL: 0.1,
+                    DamageInstanceClass.MAGICAL: 0.05,
+                },
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def second_wind(self):
+        name = "Second Wind"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=800),
+        )
+
+    @GenericJobClass.is_a_skill
+    def bloodbath(self):
+        name = "Bloodbath"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            # TODO: add defensive spec
+        )
+
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
 
+    # Ten, Chi, Jin are "gcds" or act like it, but they are technically abilities.
     @GenericJobClass.is_a_skill
     def ten(self):
         name = "Ten"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__mudra_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,
+            skill_type=SkillType.ABILITY,  # Mudras are actually "Ability" skills
+            timing_spec=self.__mudra_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def chi(self):
         name = "Chi"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__mudra_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,
+            skill_type=SkillType.ABILITY,  # Mudras are actually "Ability" skills
+            timing_spec=self.__mudra_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def jin(self):
         name = "Jin"
-        return Skill(name=name, is_GCD=True, timing_spec=self.__mudra_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=True,  # Mudras are actually "Ability" skills
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.__mudra_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def true_north(self):
         name = "True North"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def hide(self):
         name = "Hide"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
