@@ -131,18 +131,21 @@ ALL_DATA = {
     },
     "Dokumori": {
         90: {
-            "potency": {"7.0": 300},
+            "potency": {"7.0": 300, "7.3": 400},
             "duration": {"7.0": int(21.02 * 1000)},
             "aoe_dropoff": {"7.0": 0, "7.1": 0.25, "7.2": 0},
         },
         100: {
-            "potency": {"7.0": 300},
+            "potency": {"7.0": 300, "7.3": 400},
             "duration": {"7.0": int(21.02 * 1000)},
             "aoe_dropoff": {"7.0": 0, "7.1": 0.25, "7.2": 0},
         },
     },
     "Huraijin": {90: {"potency": {"6.55": 200}}},
-    "Hellfrog Medium": {90: {"potency": {"6.55": 160}}, 100: {"potency": {"7.0": 160}}},
+    "Hellfrog Medium": {
+        90: {"potency": {"6.55": 160, "7.3": 250}},
+        100: {"potency": {"7.0": 160, "7.3": 250}},
+    },
     "Bhavacakra": {
         90: {"potency": {"6.55": 350}, "potency_mesui": {"6.55": 500}},
         100: {
@@ -152,11 +155,11 @@ ALL_DATA = {
     },
     "Phantom Kamaitachi (pet)": {
         90: {
-            "potency": {"6.55": 600},
+            "potency": {"6.55": 600, "7.3": 700},
             "aoe_dropoff": {"6.55": 0.5, "7.2": 0.25, "7.25": 0},
         },
         100: {
-            "potency": {"7.0": 600},
+            "potency": {"7.0": 600, "7.3": 700},
             "aoe_dropoff": {"7.0": 0.5, "7.2": 0.25, "7.25": 0},
         },
     },
@@ -177,7 +180,10 @@ ALL_DATA = {
         100: {"damage_spec": {"7.0": DamageSpec(potency=240)}},
     },
     "Suiton": {90: {"potency": {"6.55": 500}}, 100: {"potency": {"7.0": 580}}},
-    "Goka Mekkyaku": {90: {"potency": {"6.55": 600}}, 100: {"potency": {"7.0": 600}}},
+    "Goka Mekkyaku": {
+        90: {"potency": {"6.55": 600, "7.4": 850}},
+        100: {"potency": {"7.0": 600, "7.4": 850}},
+    },
     "Hyosho Ranryu": {90: {"potency": {"6.55": 1300}}, 100: {"potency": {"7.0": 1300}}},
     "Meisui": {
         90: {"allowlist": {"6.55": ("Bhavacakra",)}},
@@ -185,12 +191,12 @@ ALL_DATA = {
     },
     "Kunai's Bane": {
         100: {
-            "potency": {"7.0": 600},
+            "potency": {"7.0": 600, "7.3": 700},
             "duration": {"7.0": int(16.26 * 1000)},
             "aoe_dropoff": {"7.0": 0.5, "7.2": 0.25, "7.25": 0},
         }
     },
-    "Deathfrog Medium": {100: {"potency": {"7.0": 300, "7.2": 260}}},
+    "Deathfrog Medium": {100: {"potency": {"7.0": 300, "7.2": 260, "7.3": 400}}},
     "Zesho Meppo": {
         100: {
             "potency": {"7.0": 550, "7.05": 700},
