@@ -111,22 +111,28 @@ ALL_DATA = {
         90: {
             "base_potency": {"6.55": 720},
             "potency_increment": {"6.55": 40},
-            "aoe_dropoff": {"6.55": 0.6, "7.2": 0.4},
+            "aoe_dropoff": {"6.55": 0.6, "7.2": 0.4, "7.3": 0.2},
         },
         100: {
             "base_potency": {"7.0": 720},
             "potency_increment": {"7.0": 40},
-            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.4},
+            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.4, "7.3": 0.2},
         },
     },
     "Communio": {
-        90: {"potency": {"6.55": 1100}, "aoe_dropoff": {"6.55": 0.6, "7.2": 0.4}},
-        100: {"potency": {"7.0": 1100}, "aoe_dropoff": {"7.0": 0.6, "7.2": 0.4}},
+        90: {
+            "potency": {"6.55": 1100},
+            "aoe_dropoff": {"6.55": 0.6, "7.2": 0.4, "7.3": 0.2},
+        },
+        100: {
+            "potency": {"7.0": 1100},
+            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.4, "7.3": 0.2},
+        },
     },
     "Sacrificium": {
         100: {
             "potency": {"7.0": 530, "7.2": 600},
-            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4},
+            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4, "7.3": 0.2},
         }
     },
     "Executioner's Gibbet": {
@@ -149,7 +155,7 @@ ALL_DATA = {
     "Perfectio": {
         100: {
             "potency": {"7.0": 1200, "7.05": 1300},
-            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.4},
+            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.4, "7.3": 0.2},
         }
     },
 }
