@@ -2,13 +2,20 @@ import numpy as np
 
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
 from ama_xiv_combat_sim.simulator.specs.job_resource_settings import JobResourceSettings
 from ama_xiv_combat_sim.simulator.specs.job_resource_spec import JobResourceSpec
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.ranged.brd_data import (
@@ -87,6 +94,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.shot_timing_spec,
             damage_spec=DamageSpec(
                 potency=80, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -98,7 +106,6 @@ class BrdSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency(name),
                     damage_class=DamageClass.PHYSICAL_DOT,
@@ -115,7 +122,6 @@ class BrdSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency(name),
                     damage_class=DamageClass.PHYSICAL_DOT,
@@ -133,8 +139,7 @@ class BrdSkills(GenericJobClass):
         army_paeon_rep1 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.04,
                     auto_attack_delay_reduction=0.04,
                     duration=45 * 1000,
@@ -145,8 +150,7 @@ class BrdSkills(GenericJobClass):
         army_paeon_rep2 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.08,
                     auto_attack_delay_reduction=0.08,
                     duration=45 * 1000,
@@ -157,8 +161,7 @@ class BrdSkills(GenericJobClass):
         army_paeon_rep3 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.12,
                     auto_attack_delay_reduction=0.12,
                     duration=45 * 1000,
@@ -169,8 +172,7 @@ class BrdSkills(GenericJobClass):
         army_paeon_rep4 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.16,
                     auto_attack_delay_reduction=0.16,
                     duration=45 * 1000,
@@ -182,6 +184,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=(
                 None
                 if self._version >= "7.0"
@@ -197,8 +200,8 @@ class BrdSkills(GenericJobClass):
                     "4 Repertoire": None,
                 }
             ),
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     dh_rate_add=0.03,
                     duration=45 * 1000,
                     is_party_effect=True,
@@ -208,7 +211,7 @@ class BrdSkills(GenericJobClass):
                         "Mage's Ballad",
                     ),
                 ),
-                "Buff Only": StatusEffectSpec(
+                "Buff Only": OffensiveStatusEffectSpec(
                     dh_rate_add=0.03,
                     duration=45 * 1000,
                     is_party_effect=True,
@@ -218,7 +221,7 @@ class BrdSkills(GenericJobClass):
                         "Mage's Ballad",
                     ),
                 ),
-                "From Log, Buff Only": StatusEffectSpec(
+                "From Log, Buff Only": OffensiveStatusEffectSpec(
                     dh_rate_add=0.03,
                     duration=5 * 1000,
                     max_duration=5 * 1000,
@@ -229,7 +232,7 @@ class BrdSkills(GenericJobClass):
                         "Mage's Ballad",
                     ),
                 ),
-                "From Log": StatusEffectSpec(
+                "From Log": OffensiveStatusEffectSpec(
                     dh_rate_add=0.03,
                     duration=5 * 1000,
                     max_duration=5 * 1000,
@@ -284,8 +287,7 @@ class BrdSkills(GenericJobClass):
                 FollowUp(
                     skill=Skill(
                         name=name,
-                        is_GCD=False,
-                        buff_spec=StatusEffectSpec(
+                        offensive_buff_spec=OffensiveStatusEffectSpec(
                             haste_time_reduction=haste_and_auto_time_reductions[i],
                             auto_attack_delay_reduction=haste_and_auto_time_reductions[
                                 i
@@ -304,7 +306,10 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            buff_spec=StatusEffectSpec(damage_mult=1.15, duration=int(19.98 * 1000)),
+            skill_type=SkillType.ABILITY,
+            offensive_buff_spec=OffensiveStatusEffectSpec(
+                damage_mult=1.15, duration=int(19.98 * 1000)
+            ),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=540
             ),
@@ -316,6 +321,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1600
@@ -339,12 +345,13 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: mages_ballad_potency,
                 "Buff Only": None,
             },
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     damage_mult=1.01,
                     duration=45 * 1000,
                     is_party_effect=True,
@@ -353,7 +360,7 @@ class BrdSkills(GenericJobClass):
                         "Army's Paeon",
                     ),
                 ),
-                "Buff Only": StatusEffectSpec(
+                "Buff Only": OffensiveStatusEffectSpec(
                     damage_mult=1.01,
                     duration=45 * 1000,
                     is_party_effect=True,
@@ -362,7 +369,7 @@ class BrdSkills(GenericJobClass):
                         "Army's Paeon",
                     ),
                 ),
-                "From Log, Buff Only": StatusEffectSpec(
+                "From Log, Buff Only": OffensiveStatusEffectSpec(
                     damage_mult=1.01,
                     duration=5 * 1000,
                     max_duration=5 * 1000,
@@ -373,7 +380,7 @@ class BrdSkills(GenericJobClass):
                         "Army's Paeon",
                     ),
                 ),
-                "From Log": StatusEffectSpec(
+                "From Log": OffensiveStatusEffectSpec(
                     damage_mult=1.01,
                     duration=5 * 1000,
                     max_duration=5 * 1000,
@@ -409,6 +416,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1650
@@ -422,7 +430,8 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            buff_spec=StatusEffectSpec(
+            skill_type=SkillType.ABILITY,
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 dh_rate_add=0.20,
                 duration=self._skill_data.get_skill_data(name, "duration"),
                 is_party_effect=True,
@@ -448,12 +457,13 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: wanderers_potency,
                 "Buff Only": None,
             },
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     crit_rate_add=0.02,
                     duration=45 * 1000,
                     is_party_effect=True,
@@ -462,7 +472,7 @@ class BrdSkills(GenericJobClass):
                         "Mage's Ballad",
                     ),
                 ),
-                "Buff Only": StatusEffectSpec(
+                "Buff Only": OffensiveStatusEffectSpec(
                     crit_rate_add=0.02,
                     duration=45 * 1000,
                     is_party_effect=True,
@@ -471,7 +481,7 @@ class BrdSkills(GenericJobClass):
                         "Mage's Ballad",
                     ),
                 ),
-                "From Log, Buff Only": StatusEffectSpec(
+                "From Log, Buff Only": OffensiveStatusEffectSpec(
                     crit_rate_add=0.02,
                     duration=5 * 1000,
                     max_duration=5 * 1000,
@@ -482,7 +492,7 @@ class BrdSkills(GenericJobClass):
                         "Mage's Ballad",
                     ),
                 ),
-                "From Log": StatusEffectSpec(
+                "From Log": OffensiveStatusEffectSpec(
                     crit_rate_add=0.02,
                     duration=5 * 1000,
                     max_duration=5 * 1000,
@@ -518,6 +528,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_skill_data(name, "3 Repertoire")
@@ -546,6 +557,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1030
@@ -562,6 +574,7 @@ class BrdSkills(GenericJobClass):
             iron_jaws_skill = Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=670
@@ -594,6 +607,7 @@ class BrdSkills(GenericJobClass):
             iron_jaws_skill = Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=670
@@ -633,6 +647,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=530
@@ -648,6 +663,7 @@ class BrdSkills(GenericJobClass):
             caustic_bite_skill = Skill(
                 name=name,
                 is_GCD=False,
+                skill_type=SkillType.ABILITY,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=1290
@@ -673,6 +689,7 @@ class BrdSkills(GenericJobClass):
             caustic_bite_skill = Skill(
                 name=name,
                 is_GCD=False,
+                skill_type=SkillType.ABILITY,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=1290
@@ -697,6 +714,7 @@ class BrdSkills(GenericJobClass):
             stormbite_skill = Skill(
                 name=name,
                 is_GCD=False,
+                skill_type=SkillType.ABILITY,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=1290
@@ -707,7 +725,6 @@ class BrdSkills(GenericJobClass):
             stormbite_barrage2 = FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 delay_after_parent_application=120,
@@ -715,7 +732,6 @@ class BrdSkills(GenericJobClass):
             stormbite_barrage3 = FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 delay_after_parent_application=240,
@@ -723,6 +739,7 @@ class BrdSkills(GenericJobClass):
             stormbite_skill = Skill(
                 name=name,
                 is_GCD=False,
+                skill_type=SkillType.ABILITY,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=1290
@@ -744,7 +761,6 @@ class BrdSkills(GenericJobClass):
         refulgent_arrow_barrage2 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             ),
             delay_after_parent_application=120,
@@ -752,7 +768,6 @@ class BrdSkills(GenericJobClass):
         refulgent_arrow_barrage3 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             ),
             delay_after_parent_application=240,
@@ -760,6 +775,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1470
@@ -776,6 +792,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_skill_data(name, "potency")
@@ -797,6 +814,7 @@ class BrdSkills(GenericJobClass):
             burst_shot_skill = Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=1470
@@ -806,7 +824,6 @@ class BrdSkills(GenericJobClass):
             burst_shot_barrage2 = FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 delay_after_parent_application=120,
@@ -814,7 +831,6 @@ class BrdSkills(GenericJobClass):
             burst_shot_barrage3 = FollowUp(
                 skill=Skill(
                     name=name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 ),
                 delay_after_parent_application=240,
@@ -822,6 +838,7 @@ class BrdSkills(GenericJobClass):
             burst_shot_skill = Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
                 timing_spec=TimingSpec(
                     base_cast_time=0, animation_lock=650, application_delay=1470
@@ -839,6 +856,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_skill_data(name, "100 Soul Voice")
@@ -908,7 +926,6 @@ class BrdSkills(GenericJobClass):
         ladonsbite_barrage2 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             ),
             delay_after_parent_application=120,
@@ -916,7 +933,6 @@ class BrdSkills(GenericJobClass):
         ladonsbite_barrage3 = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             ),
             delay_after_parent_application=240,
@@ -924,6 +940,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1110
@@ -941,6 +958,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -960,8 +978,7 @@ class BrdSkills(GenericJobClass):
         encore1 = FollowUp(
             skill=Skill(
                 name="1 Encore",
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
                     duration=30 * 1000,
@@ -976,8 +993,7 @@ class BrdSkills(GenericJobClass):
         encore2 = FollowUp(
             skill=Skill(
                 name="2 Encore",
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
                     duration=30 * 1000,
@@ -992,8 +1008,7 @@ class BrdSkills(GenericJobClass):
         encore3 = FollowUp(
             skill=Skill(
                 name="3 Encore",
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
                     duration=30 * 1000,
@@ -1009,58 +1024,59 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            skill_type=SkillType.ABILITY,
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     damage_mult=1.06,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Mage's Coda": StatusEffectSpec(
+                "1 Mage's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.02,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Army's Coda": StatusEffectSpec(
+                "1 Army's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.02,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Wanderer's Coda": StatusEffectSpec(
+                "1 Wanderer's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.02,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Mage's Coda, 1 Army's Coda": StatusEffectSpec(
+                "1 Mage's Coda, 1 Army's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.04,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Mage's Coda, 1 Wanderer's Coda": StatusEffectSpec(
+                "1 Mage's Coda, 1 Wanderer's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.04,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Army's Coda, 1 Wanderer's Coda": StatusEffectSpec(
+                "1 Army's Coda, 1 Wanderer's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.04,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Mage's Coda, 1 Army's Coda, 1 Wanderer's Coda": StatusEffectSpec(
+                "1 Mage's Coda, 1 Army's Coda, 1 Wanderer's Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.06,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "1 Coda": StatusEffectSpec(
+                "1 Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.02,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "2 Coda": StatusEffectSpec(
+                "2 Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.04,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
                 ),
-                "3 Coda": StatusEffectSpec(
+                "3 Coda": OffensiveStatusEffectSpec(
                     damage_mult=1.06,
                     duration=self._skill_data.get_skill_data(name, "duration"),
                     is_party_effect=True,
@@ -1097,11 +1113,16 @@ class BrdSkills(GenericJobClass):
                     "1 Coda": tuple(),
                     "2 Coda": tuple(),
                     "3 Coda": tuple(),
+                    # for backwards compatibility
+                    "1 Coda, Buff Only": tuple(),
+                    "2 Coda, Buff Only": tuple(),
+                    "3 Coda, Buff Only": tuple(),
+                    "Buff Only": tuple(),
                 }
                 if self._level >= 100
                 else tuple()
             ),
-            off_class_default_condition="Buff Only"
+            off_class_default_condition="3 Coda",
         )
 
     @GenericJobClass.is_a_skill
@@ -1110,8 +1131,9 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=10 * 1000,
@@ -1142,6 +1164,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1650
@@ -1156,6 +1179,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -1176,6 +1200,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_skill_data(name, "3 Encore")
@@ -1197,12 +1222,77 @@ class BrdSkills(GenericJobClass):
             aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
+    @GenericJobClass.is_a_skill
+    def second_wind(self):
+        name = "Second Wind"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=800),
+        )
+
+    @GenericJobClass.is_a_skill
+    def troubadour(self):
+        name = "Troubadour"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=all_brd_skills.get_skill_data(
+                    name, "damage_reduction"
+                ),
+                does_not_stack_with=frozenset(("Shield Samba", "Tactician")),
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def natures_minne(self):
+        name = "Nature's Minne"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                hp_recovery_up_via_healing_actions=0.15,
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def repelling_shot(self):
+        name = "Repelling Shot"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
+
+    @GenericJobClass.is_a_skill
+    def the_wardens_paean(self):
+        name = "The Warden's Paean"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
+
     @GenericJobClass.is_a_skill
     def add_soul_voice(self):
         name = "Add Soul Voice"
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=0, application_delay=0
             ),
@@ -1239,6 +1329,7 @@ class BrdSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=0, application_delay=0
             ),
