@@ -59,6 +59,7 @@ ALL_DATA = {
         90: {"potency": {"6.55": 220, "7.0": 200}},
         100: {"potency": {"7.0": 220}},
     },
+    # TODO: fix lvl 90. Need to see in game.
     "Apex Arrow": {
         90: {
             "20 Soul Voice": {"6.55": 100},
@@ -80,23 +81,23 @@ ALL_DATA = {
             "100 Soul Voice": {"6.55": 500},
         },
         100: {
-            "20 Soul Voice": {"7.0": 120},
-            "25 Soul Voice": {"7.0": 150},
-            "30 Soul Voice": {"7.0": 180},
-            "35 Soul Voice": {"7.0": 210},
-            "40 Soul Voice": {"7.0": 240},
-            "45 Soul Voice": {"7.0": 270},
-            "50 Soul Voice": {"7.0": 300},
-            "55 Soul Voice": {"7.0": 330},
-            "60 Soul Voice": {"7.0": 360},
-            "65 Soul Voice": {"7.0": 390},
-            "70 Soul Voice": {"7.0": 420},
-            "75 Soul Voice": {"7.0": 450},
-            "80 Soul Voice": {"7.0": 480},
-            "85 Soul Voice": {"7.0": 510},
-            "90 Soul Voice": {"7.0": 540},
-            "95 Soul Voice": {"7.0": 570},
-            "100 Soul Voice": {"7.0": 600},
+            "20 Soul Voice": {"7.0": 120, "7.4": 140},
+            "25 Soul Voice": {"7.0": 150, "7.4": 140 + int(1 * 35)},
+            "30 Soul Voice": {"7.0": 180, "7.4": 140 + int(2 * 35)},
+            "35 Soul Voice": {"7.0": 210, "7.4": 140 + int(3 * 355)},
+            "40 Soul Voice": {"7.0": 240, "7.4": 140 + int(4 * 35)},
+            "45 Soul Voice": {"7.0": 270, "7.4": 140 + int(5 * 35)},
+            "50 Soul Voice": {"7.0": 300, "7.4": 140 + int(6 * 35)},
+            "55 Soul Voice": {"7.0": 330, "7.4": 140 + int(7 * 35)},
+            "60 Soul Voice": {"7.0": 360, "7.4": 140 + int(8 * 35)},
+            "65 Soul Voice": {"7.0": 390, "7.4": 140 + int(9 * 35)},
+            "70 Soul Voice": {"7.0": 420, "7.4": 140 + int(10 * 35)},
+            "75 Soul Voice": {"7.0": 450, "7.4": 140 + int(11 * 35)},
+            "80 Soul Voice": {"7.0": 480, "7.4": 140 + int(12 * 35)},
+            "85 Soul Voice": {"7.0": 510, "7.4": 140 + int(13 * 35)},
+            "90 Soul Voice": {"7.0": 540, "7.4": 140 + int(14 * 35)},
+            "95 Soul Voice": {"7.0": 570, "7.4": 140 + int(15 * 35)},
+            "100 Soul Voice": {"7.0": 600, "7.4": 700},
         },
     },
     "Ladonsbite": {
@@ -104,8 +105,14 @@ ALL_DATA = {
         100: {"potency": {"7.0": 130, "7.2": 140}},
     },
     "Blast Arrow": {
-        90: {"potency": {"6.55": 600}, "aoe_dropoff": {"7.0": 0.6, "7.25": 0.5}},
-        100: {"potency": {"7.0": 600}, "aoe_dropoff": {"7.0": 0.6, "7.25": 0.5}},
+        90: {
+            "potency": {"6.55": 600, "7.4": 700},
+            "aoe_dropoff": {"7.0": 0.6, "7.25": 0.5},
+        },
+        100: {
+            "potency": {"7.0": 600, "7.4": 700},
+            "aoe_dropoff": {"7.0": 0.6, "7.25": 0.5},
+        },
     },
     "Radiant Finale": {
         90: {"duration": {"6.55": 15 * 1000, "7.0": 20 * 1000}},
@@ -114,18 +121,26 @@ ALL_DATA = {
     "Heartbreak Shot": {100: {"potency": {"7.0": 180}}},
     "Resonant Arrow": {
         100: {
-            "potency": {"7.0": 600},
+            "potency": {"7.0": 600, "7.3": 640},
             "aoe_dropoff": {"7.0": 0.5, "7.2": 0.55, "7.25": 0.5},
         }
     },
     "Radiant Encore": {
         100: {
-            "3 Encore": {"7.0": 900},
-            "2 Encore": {"7.0": 600},
-            "1 Encore": {"7.0": 500},
+            "3 Encore": {"7.0": 900, "7.3": 1000, "7.4": 1100},
+            "2 Encore": {"7.0": 600, "7.3": 700, "7.4": 800},
+            "1 Encore": {"7.0": 500, "7.3": 600, "7.4": 700},
             "aoe_dropoff": {"7.0": 0.5, "7.2": 0.55, "7.25": 0.5},
         }
     },
+    "Troubadour": {
+        90: {
+            "damage_reduction": {"6.55": 0.1},
+        },
+        100: {
+            "damage_reduction": {"6.55": 0.15},
+        },
+    },
 }
 
 for k, v in ALL_DATA.items():
