@@ -1,12 +1,20 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.ranged.dnc_data import (
@@ -24,9 +32,8 @@ class DncSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
-                    damage_mult=1.05, duration=60000, is_party_effect=True
+                offensive_buff_spec=OffensiveStatusEffectSpec(
+                    damage_mult=1.05, duration=60000, is_party_effect=True, is_single_target=True
                 ),
             ),
             delay_after_parent_application=0,
@@ -40,6 +47,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.shot_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -52,6 +60,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -65,6 +74,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Cascade",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -85,6 +95,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -102,9 +113,8 @@ class DncSkills(GenericJobClass):
         _standard_finish1_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
-                    damage_mult=1.02, duration=60000, is_party_effect=True
+                offensive_buff_spec=OffensiveStatusEffectSpec(
+                    damage_mult=1.02, duration=60000, is_party_effect=True, is_single_target=True
                 ),
             ),
             delay_after_parent_application=0,
@@ -115,8 +125,7 @@ class DncSkills(GenericJobClass):
         _standard_remove_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     expires_status_effects=("Standard Finish",), is_party_effect=True
                 ),
             ),
@@ -174,6 +183,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Standard Finish", "aoe_dropoff"
@@ -204,6 +214,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Standard Finish", "aoe_dropoff"
@@ -234,6 +245,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Standard Finish", "aoe_dropoff"
@@ -271,6 +283,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -283,6 +296,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Windmill",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -304,6 +318,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -316,6 +331,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -329,6 +345,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1210
@@ -341,6 +358,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -354,6 +372,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=530
@@ -367,15 +386,17 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: self.instant_timing_spec,
                 "Dance Partner": TimingSpec(base_cast_time=0, animation_lock=0),
             },
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 crit_rate_add=0.20,
                 dh_rate_add=0.20,
                 duration=self._skill_data.get_skill_data(name, "duration"),
                 is_party_effect=True,
+                is_single_target=True,
             ),
         )
 
@@ -385,6 +406,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -405,8 +427,7 @@ class DncSkills(GenericJobClass):
         tech4_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.05, duration=int(20.45 * 1000), is_party_effect=True
                 ),
             ),
@@ -417,8 +438,7 @@ class DncSkills(GenericJobClass):
         tech3_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.03, duration=int(20.45 * 1000), is_party_effect=True
                 ),
             ),
@@ -429,8 +449,7 @@ class DncSkills(GenericJobClass):
         tech2_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.02, duration=int(20.45 * 1000), is_party_effect=True
                 ),
             ),
@@ -441,8 +460,7 @@ class DncSkills(GenericJobClass):
         tech1_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.01, duration=int(20.45 * 1000), is_party_effect=True
                 ),
             ),
@@ -453,8 +471,7 @@ class DncSkills(GenericJobClass):
         tech4_longest_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.05, duration=int(20.95 * 1000), is_party_effect=True
                 ),
             ),
@@ -465,8 +482,7 @@ class DncSkills(GenericJobClass):
         tech3_longest_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.03, duration=int(20.95 * 1000), is_party_effect=True
                 ),
             ),
@@ -477,8 +493,7 @@ class DncSkills(GenericJobClass):
         tech2_longest_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.02, duration=int(20.95 * 1000), is_party_effect=True
                 ),
             ),
@@ -489,8 +504,7 @@ class DncSkills(GenericJobClass):
         tech1_longest_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=1.01, duration=int(20.95 * 1000), is_party_effect=True
                 ),
             ),
@@ -502,8 +516,7 @@ class DncSkills(GenericJobClass):
         tech_remove_followup = FollowUp(
             Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     expires_status_effects=("Technical Finish",),
                     is_party_effect=True,
                 ),
@@ -525,6 +538,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Technical Finish", "aoe_dropoff"
@@ -557,6 +571,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Technical Finish", "aoe_dropoff"
@@ -589,6 +604,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Technical Finish", "aoe_dropoff"
@@ -621,6 +637,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Technical Finish", "aoe_dropoff"
@@ -653,6 +670,7 @@ class DncSkills(GenericJobClass):
             Skill(
                 name=name,
                 is_GCD=True,
+                skill_type=SkillType.WEAPONSKILL,
                 has_aoe=True,
                 aoe_dropoff=self._skill_data.get_skill_data(
                     "Technical Finish", "aoe_dropoff"
@@ -695,6 +713,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -713,6 +732,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             has_aoe=True,
             aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
@@ -745,16 +765,21 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 gcd_base_recast_time=1500,
                 affected_by_speed_stat=False,
             ),
-            follow_up_skills=(
-                finishing_move_damage_follow_up,
-                self.__get_standard_finish2_follow_up(),
-            ),
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: (
+                    finishing_move_damage_follow_up,
+                    self.__get_standard_finish2_follow_up(),
+                ),
+                "Buff Only": (self.__get_standard_finish2_follow_up(),),
+            },
             has_aoe=True,
+            off_class_default_condition="Buff Only",
         )
 
     @GenericJobClass.is_a_skill
@@ -763,6 +788,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -781,6 +807,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name),
@@ -803,6 +830,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -823,6 +851,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -835,6 +864,81 @@ class DncSkills(GenericJobClass):
             aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
+    @GenericJobClass.is_a_skill
+    def second_wind(self):
+        name = "Second Wind"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=800),
+        )
+
+    @GenericJobClass.is_a_skill
+    def improvisation(self):
+        name = "Improvisation"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            # TODO: have a way to cut the heal
+            heal_spec=HealSpec(
+                hot_potency=100, duration=15 * 1000, is_party_effect=True, is_aoe=True
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def improvised_finish(self):
+        def get_shield_spec(shield_on_max_hp):
+            return ShieldSpec(shield_on_max_hp=shield_on_max_hp, duration=30 * 1000)
+
+        name = "Improvised Finish"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            shield_spec={
+                SimConsts.DEFAULT_CONDITION: get_shield_spec(0.10),
+                "0 Rising Rhythm": get_shield_spec(0.05),
+                "1 Rising Rhythm": get_shield_spec(0.06),
+                "2 Rising Rhythm": get_shield_spec(0.07),
+                "3 Rising Rhythm": get_shield_spec(0.08),
+                "4 Rising Rhythm": get_shield_spec(0.10),
+            },
+        )
+
+    @GenericJobClass.is_a_skill
+    def curing_waltz(self):
+        name = "Curing Waltz"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=300, is_party_effect=True, is_aoe=True),
+        )
+
+    @GenericJobClass.is_a_skill
+    def shield_samba(self):
+        name = "Shield Samba"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=all_dnc_skills.get_skill_data(
+                    name, "damage_reduction"
+                ),
+                does_not_stack_with=frozenset(("Troubadour", "Tactician")),
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
@@ -845,6 +949,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 gcd_base_recast_time=1500,
@@ -858,6 +963,7 @@ class DncSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 gcd_base_recast_time=1500,
@@ -868,7 +974,10 @@ class DncSkills(GenericJobClass):
     @GenericJobClass.is_a_skill
     def flourish(self):
         return Skill(
-            name="Flourish", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Flourish",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
@@ -878,5 +987,12 @@ class DncSkills(GenericJobClass):
             base_cast_time=0, gcd_base_recast_time=1000, affected_by_speed_stat=False
         )
         for step_name in ["Emboite", "Entrechat", "Jete", "Pirouette", "Step Action"]:
-            res.append(Skill(name=step_name, is_GCD=True, timing_spec=step_timing))
+            res.append(
+                Skill(
+                    name=step_name,
+                    is_GCD=True,
+                    skill_type=SkillType.WEAPONSKILL,
+                    timing_spec=step_timing,
+                )
+            )
         return res
