@@ -1,11 +1,22 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.tank.drk_data import (
@@ -22,7 +33,7 @@ class DrkSkills(GenericJobClass):
         name = "Darkside"
         return Skill(
             name=name,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 duration=30000, max_duration=60000, damage_mult=1.10
             ),
         )
@@ -33,6 +44,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -45,6 +57,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -58,6 +71,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Hard Slash",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -78,6 +92,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -92,6 +107,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=978
@@ -104,6 +120,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Syphon Strike",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -133,6 +150,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=624
             ),
@@ -153,6 +171,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             combo_spec=(ComboSpec(combo_actions=("Unleash",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -182,6 +201,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
             ),
@@ -198,7 +218,6 @@ class DrkSkills(GenericJobClass):
         name = "Salted Earth (dot)"
         salted_earth_dot_drk = Skill(
             name=name,
-            is_GCD=False,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 # It is believed that salted earth is a MAGICAL dot (unaspected damage)
@@ -211,6 +230,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=757
             ),
@@ -221,6 +241,7 @@ class DrkSkills(GenericJobClass):
                     dot_duration=15 * 1000,
                     snapshot_buffs_with_parent=True,
                     snapshot_debuffs_with_parent=False,
+                    primary_target_only=False,
                 ),
             ),
             has_aoe=True,
@@ -232,6 +253,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -252,6 +274,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=624
@@ -264,10 +287,13 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=978
             ),
+            # TODO: need to make this not multi-heal on multi-targets. Currently, it will.
+            heal_spec=HealSpec(potency=500),
             has_aoe=True,
         )
 
@@ -277,10 +303,12 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1473
             ),
+            heal_spec=HealSpec(potency=500),
         )
 
     @GenericJobClass.is_a_skill
@@ -289,6 +317,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=802
@@ -301,6 +330,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=757
@@ -314,6 +344,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -376,7 +407,9 @@ class DrkSkills(GenericJobClass):
                 ls_names_and_potency_and_delays = [
                     (
                         "Abyssal Drain (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800,
                         False,
                         None,
@@ -392,21 +425,27 @@ class DrkSkills(GenericJobClass):
                     ),
                     (
                         "Edge of Shadow (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 3 * 2200,
                         False,
                         None,
                     ),
                     (
                         "Bloodspiller (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 4 * 2200,
                         False,
                         None,
                     ),
                     (
                         "Carve and Spit (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 5 * 2200,
                         False,
                         None,
@@ -416,14 +455,18 @@ class DrkSkills(GenericJobClass):
                 ls_names_and_potency_and_delays = [
                     (
                         "Abyssal Drain (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800,
                         False,
                         None,
                     ),
                     (
                         "Plunge (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 2200,
                         False,
                         None,
@@ -439,21 +482,27 @@ class DrkSkills(GenericJobClass):
                     ),
                     (
                         "Edge of Shadow (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 3 * 2200,
                         False,
                         None,
                     ),
                     (
                         "Bloodspiller (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 4 * 2200,
                         False,
                         None,
                     ),
                     (
                         "Carve and Spit (pet)",
-                        self._skill_data.get_skill_data("Living Shadow", "potency_base"),
+                        self._skill_data.get_skill_data(
+                            "Living Shadow", "potency_base"
+                        ),
                         6800 + 5 * 2200,
                         False,
                         None,
@@ -471,7 +520,6 @@ class DrkSkills(GenericJobClass):
             fu = FollowUp(
                 skill=Skill(
                     name=skill_name,
-                    is_GCD=False,
                     damage_spec=DamageSpec(
                         potency=potency,
                         damage_class=DamageClass.PET,
@@ -492,6 +540,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             follow_up_skills=_living_shadow_follow_ups,
             timing_spec=self.instant_timing_spec,
             status_effect_denylist=("Darkside", "Dragon Sight"),
@@ -506,6 +555,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=581
@@ -521,6 +571,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=670
@@ -536,6 +587,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -551,6 +603,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=980
@@ -567,6 +620,7 @@ class DrkSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -579,62 +633,275 @@ class DrkSkills(GenericJobClass):
             aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
+    @GenericJobClass.is_a_skill
+    def shadow_wall(self):
+        if self._level >= 92:
+            return None
+        return Skill(
+            name="Shadow Wall",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.3,
+                duration=15 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def shadow_vigil_expire(self):
+        if self._level < 92:
+            return None
+        return Skill(
+            name="Shadow Vigil (Expire)",
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "Shadow Vigil": HealSpec(potency=1200),
+            },
+            # This isn't necessary, but let's be just a bit defensive here.
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                expires_status_effects=("Shadow Vigil",)
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def shadow_vigil_heal(self):
+        if self._level < 92:
+            return None
+        return Skill(
+            name="Shadow Vigil (Heal)",
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec=HealSpec(potency=1200),
+        )
+
+    @GenericJobClass.is_a_skill
+    def shadow_vigil(self):
+        if self._level < 92:
+            return None
+
+        return Skill(
+            name="Shadow Vigil",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.4,
+                duration=15 * 1000,
+                add_to_skill_modifier_condition=True,
+            ),
+            follow_up_skills=(
+                FollowUp(
+                    skill=self.shadow_vigil_expire(),
+                    delay_after_parent_application=15 * 1000,
+                ),
+            ),
+        )
+
+    # for logs convenience
+    @GenericJobClass.is_a_skill
+    def shadowed_vigil(self):
+        if self._level < 92:
+            return None
+
+        return Skill(
+            name="Shadowed Vigil",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "From Log": DefensiveStatusEffectSpec(
+                    damage_reductions=0.4,
+                    duration=15 * 1000,
+                    add_to_skill_modifier_condition=True,
+                ),
+            },
+        )
+
+    @GenericJobClass.is_a_skill
+    def dark_mind(self):
+        return Skill(
+            name="Dark Mind",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions={
+                    DamageInstanceClass.PHYSICAL: 0.1,
+                    DamageInstanceClass.MAGICAL: 0.2,
+                },
+                duration=10 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def dark_missionary(self):
+        return Skill(
+            name="Dark Missionary",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions={
+                    DamageInstanceClass.PHYSICAL: 0.05,
+                    DamageInstanceClass.MAGICAL: 0.1,
+                },
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def walking_dead(self):
+        return Skill(
+            name="Walking Dead",
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                is_invuln=True,
+                duration=10 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def living_dead_heal(self):
+        return Skill(
+            name="Living Dead (Heal)",
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec=HealSpec(potency=1500),
+        )
+
+    @GenericJobClass.is_a_skill
+    def living_dead(self):
+        return Skill(
+            name="Living Dead",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
+
+    @GenericJobClass.is_a_skill
+    def rampart(self):
+        return Skill(
+            name="Rampart",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.2,
+                hp_recovery_up_via_healing_actions=0.15,
+                duration=20 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def reprisal(self):
+        return Skill(
+            name="Reprisal",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=15 * 1000,
+            ),
+        )
+
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
 
-    @GenericJobClass.is_a_skill
-    def rampart(self):
-        return Skill(name="Rampart", is_GCD=False, timing_spec=self.instant_timing_spec)
-
     @GenericJobClass.is_a_skill
     def provoke(self):
-        return Skill(name="Provoke", is_GCD=False, timing_spec=self.instant_timing_spec)
-
-    @GenericJobClass.is_a_skill
-    def reprisal(self):
         return Skill(
-            name="Reprisal", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Provoke",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def arms_length(self):
         return Skill(
-            name="Arm's Length", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Arm's Length",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def shirk(self):
-        return Skill(name="Shirk", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Shirk",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def delirium(self):
         return Skill(
-            name="Delirium", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Delirium",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def blood_weapon(self):
         return Skill(
-            name="Blood Weapon", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Blood Weapon",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def shadowstride(self):
         return Skill(
-            name="Shadowstride", is_GCD=False, timing_spec=self.instant_timing_spec
-        )
-
-    @GenericJobClass.is_a_skill
-    def the_blackest_night(self):
-        return Skill(
-            name="The Blackest Night",
+            name="Shadowstride",
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
         )
 
+    @GenericJobClass.is_a_skill
+    def the_blackest_night(self):
+        res = []
+        # For fflogs processing- fflogs encodes it as "Blackest Night" instead of
+        # the actual name, "The Blackest Night"
+        for name in ["Blackest Night", "The Blackest Night"]:
+            res.append(
+                Skill(
+                    name=name,
+                    is_GCD=False,
+                    skill_type=SkillType.ABILITY,
+                    timing_spec=self.instant_timing_spec,
+                    shield_spec=ShieldSpec(
+                        shield_on_max_hp=0.25, duration=7 * 1000, is_party_effect=True
+                    ),
+                )
+            )
+        return res
+
     @GenericJobClass.is_a_skill
     def oblation(self):
         return Skill(
-            name="Oblation", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Oblation",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=10 * 1000,
+                is_party_effect=True,
+            ),
         )
