@@ -1,11 +1,22 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.tank.gnb_data import (
@@ -35,6 +46,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -47,6 +59,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             combo_spec=(ComboSpec(combo_group=0),),
             timing_spec=TimingSpec(
@@ -60,7 +73,10 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            buff_spec=StatusEffectSpec(duration=int(19.96 * 1000), damage_mult=1.20),
+            skill_type=SkillType.ABILITY,
+            offensive_buff_spec=OffensiveStatusEffectSpec(
+                duration=int(19.96 * 1000), damage_mult=1.20
+            ),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
@@ -72,6 +88,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -81,6 +98,23 @@ class GnbSkills(GenericJobClass):
                 ),
             },
             combo_spec=(ComboSpec(combo_group=0, combo_actions=("Keen Edge",)),),
+            heal_spec={
+                SimConsts.DEFAULT_CONDITION: HealSpec(potency=200),
+                "No Combo": None,
+            },
+            shield_spec={
+                SimConsts.DEFAULT_CONDITION: ShieldSpec(shield_mult_on_hp_restored=1.0),
+                "No Combo": None,
+            },
+            defensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: DefensiveStatusEffectSpec(
+                    add_to_skill_modifier_condition=True,
+                    num_uses=1,
+                    skill_allowlist=("Heart of Corundum",),
+                    duration=30 * 1000,
+                ),
+                "No Combo": None,
+            },
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1074
             ),
@@ -92,6 +126,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             combo_spec=(ComboSpec(combo_group=2),),
             timing_spec=TimingSpec(
@@ -106,6 +141,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=716
@@ -118,6 +154,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -138,6 +175,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=714
@@ -150,6 +188,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -170,7 +209,6 @@ class GnbSkills(GenericJobClass):
         name = "Sonic Break (dot)"
         sonic_break_dot_gnb = Skill(
             name=name,
-            is_GCD=False,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 damage_class=DamageClass.PHYSICAL_DOT,
@@ -181,6 +219,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=581
             ),
@@ -189,7 +228,9 @@ class GnbSkills(GenericJobClass):
                 FollowUp(
                     skill=sonic_break_dot_gnb,
                     delay_after_parent_application=0,
-                    dot_duration=30 * 1000,
+                    dot_duration=self._skill_data.get_skill_data(
+                        "Sonic Break (dot)", "duration"
+                    ),
                     snapshot_buffs_with_parent=True,
                     snapshot_debuffs_with_parent=True,
                 ),
@@ -205,6 +246,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=491
@@ -217,6 +259,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             combo_spec=(ComboSpec(combo_group=1),),
             timing_spec=TimingSpec(
@@ -230,6 +273,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Gnashing Fang",)),),
             timing_spec=TimingSpec(
@@ -243,6 +287,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Savage Claw",)),),
             timing_spec=TimingSpec(
@@ -255,7 +300,6 @@ class GnbSkills(GenericJobClass):
         name = "Bow Shock (dot)"
         bow_shock_dot_gnb = Skill(
             name=name,
-            is_GCD=False,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 damage_class=DamageClass.PHYSICAL_DOT,
@@ -266,6 +310,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=627
             ),
@@ -288,6 +333,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=802
@@ -300,6 +346,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=757
@@ -312,6 +359,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=981
@@ -324,6 +372,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=537
@@ -337,6 +386,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=625
@@ -349,6 +399,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=758
@@ -361,6 +412,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -382,6 +434,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1160
@@ -398,6 +451,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -419,6 +473,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -439,6 +494,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -458,43 +514,87 @@ class GnbSkills(GenericJobClass):
     @GenericJobClass.is_a_skill
     def bloodfest(self):
         return Skill(
-            name="Bloodfest", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Bloodfest",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def rampart(self):
-        return Skill(name="Rampart", is_GCD=False, timing_spec=self.instant_timing_spec)
-
-    @GenericJobClass.is_a_skill
-    def provoke(self):
-        return Skill(name="Provoke", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Rampart",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.2,
+                hp_recovery_up_via_healing_actions=0.15,
+                duration=20 * 1000,
+            ),
+        )
 
     @GenericJobClass.is_a_skill
     def reprisal(self):
         return Skill(
-            name="Reprisal", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Reprisal",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=15 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def provoke(self):
+        return Skill(
+            name="Provoke",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def arms_length(self):
         return Skill(
-            name="Arm's Length", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Arm's Length",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def shirk(self):
-        return Skill(name="Shirk", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Shirk",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def camouflage(self):
         return Skill(
-            name="Camouflage", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Camouflage",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                increase_parry_rate=0.5,
+                duration=20 * 1000,
+            ),
         )
 
     @GenericJobClass.is_a_skill
     def royal_guard(self):
         return Skill(
-            name="Royal Guard", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Royal Guard",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
@@ -502,6 +602,7 @@ class GnbSkills(GenericJobClass):
         return Skill(
             name="Release Royal Guard",
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
         )
 
@@ -509,24 +610,56 @@ class GnbSkills(GenericJobClass):
     def nebula(self):
         if self._level >= 92:
             return None
-        return Skill(name="Nebula", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Nebula",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.3, duration=15 * 1000
+            ),
+        )
 
     @GenericJobClass.is_a_skill
     def great_nebula(self):
         if self._level < 92:
             return None
         return Skill(
-            name="Great Nebula", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Great Nebula",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.4,
+                max_hp_mult=1.2,
+                duration=15 * 1000,
+            ),
         )
 
     @GenericJobClass.is_a_skill
     def aurora(self):
-        return Skill(name="Aurora", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Aurora",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(
+                hot_potency=300, duration=18 * 1000, is_party_effect=True
+            ),
+        )
 
     @GenericJobClass.is_a_skill
     def superbolide(self):
         return Skill(
-            name="Superbolide", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Superbolide",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            # TODO: model the 50% hp cut
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                is_invuln=True,
+                duration=10 * 1000,
+            ),
         )
 
     @GenericJobClass.is_a_skill
@@ -534,25 +667,110 @@ class GnbSkills(GenericJobClass):
         if self._version < "7.0":
             return None
         return Skill(
-            name="Trajectory", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Trajectory",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def heart_of_light(self):
         return Skill(
-            name="Heart of Light", is_GCD=False, timing_spec=self.instant_timing_spec
-        )
-
-    @GenericJobClass.is_a_skill
-    def heart_of_stone(self):
-        return Skill(
-            name="Heart of Stone", is_GCD=False, timing_spec=self.instant_timing_spec
-        )
-
-    @GenericJobClass.is_a_skill
-    def heart_of_corundrum(self):
-        return Skill(
-            name="Heart of Corundrum",
+            name="Heart of Light",
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions={
+                    DamageInstanceClass.PHYSICAL: 0.05,
+                    DamageInstanceClass.MAGICAL: 0.1,
+                },
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def catharsis_of_corundum_heal(self):
+        name = "Catharsis of Corundum (Heal)"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "Catharsis of Corundum": HealSpec(potency=900),
+            },
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                expires_status_effects=("Catharsis of Corundum",), is_party_effect=True
+            ),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def clarity_of_corundum(self):
+        name = "Clarity of Corundum"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.15,
+                duration=4 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def heart_of_corundum(self):
+        clarity_follow_up = FollowUp(
+            skill=self.clarity_of_corundum(), delay_after_parent_application=0
+        )
+        catharsis_follow_up_heal = FollowUp(
+            skill=self.catharsis_of_corundum_heal(),
+            delay_after_parent_application=int(20.1 * 1000),
+        )
+        catharsis_follow_up_status = FollowUp(
+            skill=Skill(
+                name="Catharsis of Corundum",
+                is_GCD=False,
+                skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+                timing_spec=self.uncontrolled_timing_spec,
+                # Defensively set duration, just in case a trigger is missed.
+                defensive_buff_spec=DefensiveStatusEffectSpec(
+                    add_to_skill_modifier_condition=True,
+                    is_party_effect=True,
+                    duration=20 * 1000,
+                ),
+            ),
+            delay_after_parent_application=0,
+        )
+
+        return Skill(
+            name="Heart of Corundum",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.15,
+                duration=8 * 1000,
+                is_party_effect=True,
+                expires_status_effects=("Brutal Shell",),
+            ),
+            heal_spec={
+                "Brutal Shell": HealSpec(potency=200),
+                SimConsts.DEFAULT_CONDITION: None,
+            },
+            shield_spec={
+                "Brutal Shell": ShieldSpec(shield_mult_on_hp_restored=1.0),
+                SimConsts.DEFAULT_CONDITION: None,
+            },
+            follow_up_skills=(
+                clarity_follow_up,
+                catharsis_follow_up_status,
+                catharsis_follow_up_heal,
+            ),
         )
