@@ -10,4 +10,7 @@ def get_cast_gcd_timing_spec():
     return TimingSpec(base_cast_time=1500, animation_lock=100)
 
 def get_instant_timing_spec():
-    return TimingSpec(base_cast_time=0, animation_lock=650)
\ No newline at end of file
+    return TimingSpec(base_cast_time=0, animation_lock=650)
+
+def get_uncontrolled_timing_spec():
+    return TimingSpec(base_cast_time=0, animation_lock=0)
\ No newline at end of file
