@@ -100,7 +100,7 @@ class TestJobsUnified705(TestClass):
         rb.add_next("Storm's Path")
         rb.add_next("Fell Cleave")
         rb.add_next("Inner Chaos")
-        expected_damage = 376198.2
+        expected_damage = 373574
         expected_total_time = 32645
 
         return self.__job_class_tester.test_aggregate_rotation(
@@ -814,6 +814,46 @@ class TestJobsUnified705(TestClass):
         )
         return self.__job_class_tester.test_skills(stats, skills_and_expected_damage)
 
+    @TestClass.is_a_test
+    def test_brd_cross_radiant(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.64,
+            main_stat=3376,
+            det_stat=2114,
+            crit_stat=2557,
+            dh_stat=1254,
+            speed_stat=400,
+            job_class="MCH",
+            version=self.__version,
+            level=self.__level,
+        )
+        
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            enable_autos=False,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )
+
+        rb.add(0, "Heat Blast")
+        rb.add(1, "Radiant Finale", SkillModifier(with_condition="1 Coda"), job_class = "BRD")
+        rb.add(5,"Heat Blast")
+        rb.add(10,"Radiant Finale", SkillModifier(with_condition="2 Coda"), job_class = "BRD")
+        rb.add(15, "Heat Blast")        
+        rb.add(100, "Radiant Finale", SkillModifier(with_condition="3 Coda"), job_class = "BRD")
+        rb.add(105, "Heat Blast")
+        
+        expected = (
+            ("Heat Blast", 9708),
+            ("Heat Blast", 9902),
+            ("Heat Blast", 10096),
+            ("Heat Blast", 10290),
+        )
+        
+        return self.__job_class_tester.test_rotation_damage(rb, expected)
+
     @TestClass.is_a_test
     def test_brd_rotation_damage_instances(self):
         stats = Stats(
@@ -1487,7 +1527,7 @@ class TestJobsUnified705(TestClass):
         rb.add_next("Chi")
         rb.add_next("Raiton")
         rb.add_next("Forked Raiju")
-        expected_damage = 635900
+        expected_damage = 630286
         expected_total_time = 27228.0
 
         return self.__job_class_tester.test_aggregate_rotation(
@@ -1964,7 +2004,7 @@ class TestJobsUnified705(TestClass):
         rb.add_next("Thunder III")
 
         expected_damage = 475338
-        expected_total_time = 26620
+        expected_total_time = 26120
         return self.__job_class_tester.test_aggregate_rotation(
             rb, expected_damage, expected_total_time
         )
@@ -2277,7 +2317,7 @@ class TestJobsUnified705(TestClass):
         for e in skill_seq:
             rb.add_next(e)
 
-        expected_damage = 1113818
+        expected_damage = 1105936
         expected_total_time = 54450
 
         return self.__job_class_tester.test_aggregate_rotation(
